@@ -18,18 +18,17 @@ ispd <- par$ispd
 if(is.null(ispd)) {
    ispd <- revise.ispd(tpm=tpm)
 }
-K   <- length(ispd)
-cis <- !(is.matrix(ispd) && ncol(ispd) > 1)
 
 # Make sure that the entries of the vectors in y correspond
 # to the row names of Rho.
 check.yval(y,Rho)
 
 # If K=1 do the triv thing:
+K <- length(ispd)
 if(K==1) return(sum(log(ffun(y,Rho))))
 
 lns <- sapply(y,length)
 fy  <- ffun(y,Rho)
-rp  <- recurse(fy,tpm,ispd,lns,cis)
+rp  <- recurse(fy,tpm,ispd,lns)
 sum(log(rp$llc))
 }
